@@ -528,10 +528,11 @@ def update_ticket(request, ticket_id, public=False):
         if new_status == Ticket.RESOLVED_STATUS or ticket.resolution is None:
             ticket.resolution = comment
 
-    ticket.save(followup=f, files=files)
+    ticket.save(followup=f, files=files, send_email=True)
 
     # auto subscribe user if enabled
-    if helpdesk_settings.HELPDESK_AUTO_SUBSCRIBE_ON_TICKET_RESPONSE and request.user.is_authenticated():
+    if helpdesk_settings.HELPDESK_AUTO_SUBSCRIBE_ON_TICKET_RESPONSE \
+    and request.user.is_authenticated():
         ticketcc_string, SHOW_SUBSCRIBE = return_ticketccstring_and_show_subscribe(request.user, ticket)
         if SHOW_SUBSCRIBE:
             subscribe_staff_member_to_ticket(ticket, request.user)
@@ -880,27 +881,35 @@ def create_ticket(request):
     create_usersettings(request)
     
     if helpdesk_settings.HELPDESK_STAFF_ONLY_TICKET_OWNERS:
-        assignable_users = User.objects.filter(is_active=True, is_staff=True).order_by('username')
+        assignable_users = User.objects.filter(
+            is_active=True, is_staff=True)
     else:
-        assignable_users = User.objects.filter(is_active=True).order_by('username')
+        assignable_users = User.objects.filter(is_active=True)
+    assignable_users = assignable_users.order_by('username')
         
     if request.method == 'POST':
         form = TicketForm(request.POST, request.FILES)
-        form.fields['queue'].choices = [('', '--------')] + [[q.id, q.title] for q in Queue.objects.all()]
-        form.fields['assigned_to'].choices = [('', '--------')] + [[u.id, u.username] for u in assignable_users]
+        form.fields['queue'].choices = [('', '--------')] \
+            + [[q.id, q.title] for q in Queue.objects.all()]
+        form.fields['assigned_to'].choices = [('', '--------')] \
+            + [[u.id, u.username] for u in assignable_users]
         if form.is_valid():
             ticket = form.save(user=request.user)
             return HttpResponseRedirect(ticket.get_absolute_url())
     else:
         initial_data = {}
-        if request.user.usersettings.settings.get('use_email_as_submitter', False) and request.user.email:
+        use_email_as_submitter = request.user.usersettings.settings.get(
+            'use_email_as_submitter', False)
+        if use_email_as_submitter and request.user.email:
             initial_data['submitter_email'] = request.user.email
         if request.GET.has_key('queue'):
             initial_data['queue'] = request.GET['queue']
 
         form = TicketForm(initial=initial_data)
-        form.fields['queue'].choices = [('', '--------')] + [[q.id, q.title] for q in Queue.objects.all()]
-        form.fields['assigned_to'].choices = [('', '--------')] + [[u.id, u.username] for u in assignable_users]
+        form.fields['queue'].choices = [('', '--------')] \
+            + [[q.id, q.title] for q in Queue.objects.all()]
+        form.fields['assigned_to'].choices = [('', '--------')] \
+            + [[u.id, u.username] for u in assignable_users]
         if helpdesk_settings.HELPDESK_CREATE_TICKET_HIDE_ASSIGNED_TO:
             form.fields['assigned_to'].widget = forms.HiddenInput()
 
@@ -1203,6 +1212,7 @@ def user_settings(request):
         if form.is_valid():
             s.settings = form.cleaned_data
             s.save()
+            return HttpResponseRedirect(reverse('helpdesk_user_settings'))
     else:
         form = UserSettingsForm(s.settings)
 
